<?php
/*			SecurityClassPHP
 * Clase para trabajar con la seguridad de todos los php.
 * 		Ventajas que proporciona
 * 			Controla la seguridad para acceder a la web.
 * 			Maneja los distintos tipos de roles específicos para el sistema de gestión de campeonatos (club,federacion,administrador,gestor,etc).
 *			Devuelve las variables típicas de sesión que se usarán en el sistema
 */
//Incluyo la clase de manejo de la base de datos.
include_once('cMySQL.php');
include_once('/../bbdd/general.php');
class sCphp {
	/*Propiedades de la clase*/
	//Nombre de usuario
	private $_username;
	//Correo del usuario
	private  $_correo;
	//Organizacion a la que pertenece, si es que pertenece a alguna
	private $_organizacion;
	//Identificador de la organización
	private $_id_org;
	//Creador de la organización a la que pertenece el usuario
	private $_creator;
	//Género
	private $_sexo;
	//Pais de la organización
	private $_pais;
	//Región de la organización
	private $_region;
	//Rol que desempeña
	private $_tipo;
	//Variable registrado que especifica si el usuario está registrado
	private $_registrado;
	
	/* métodos y funciones de la clase*/
	//En el constructor creamos las variables de 
	function __construct() {
		if (isset($_SESSION['username'])) $this->_username = $_SESSION['username'];
		else $this->_username = "";
		if (isset($_SESSION['correo'])) $this->_correo = $_SESSION['correo'];
		else $this->_correo = "";
		if (isset($_SESSION['registrado'])) $this->_registrado = $_SESSION['registrado'];
		else $this->_registrado = "";
		if (isset($_SESSION['tipo'])) $this->_tipo = $_SESSION['tipo'];
		else $this->_tipo = "";
	}
	
	//Recaba datos como la organización, el país, el creador de la organización y la región a la que pertenece.
	public function recogerDatos(){
		$sql= new cMySQL();
		$sql->conectar();
		$correo = $this->_correo;
		$sql->ejecutarSQL("SELECT organizacion, idUser, tipo FROM users WHERE correo='$correo'");
		$numRegistros=$sql->getNumRegistros();
		if ($numRegistros >0){
			$resultado=$sql->getUnRegistro();
			$this->_organizacion=$resultado['organizacion'];
			$idUser=$resultado['idUser'];
			$tipo=$resultado['tipo'];
			$organizacion=$this->_organizacion;
			$sql->ejecutarSQL("SELECT idOrg, creador, pais, region FROM organizacion WHERE nombre='$organizacion'");
			$numRegistros=$sql->getNumRegistros();
			if ($numRegistros >0){
				$resCreator=$sql->getUnRegistro();
				$this->_creator=$resCreator['creador'];
				$this->_pais=$resCreator['pais'];
				$this->_region=$resCreator['region'];
				$this->_id_org=$resCreator['idOrg'];
			}
			else{
				$this->_creator="";
				$this->_pais="";
				$this->_region="";
			}
			if ($tipo=='alumno'){
				$sql->ejecutarSQL("SELECT sexo FROM alumno WHERE id_user='$idUser'");
				$resultado2=$sql->getUnRegistro();
				$this->_sexo=$resultado2['sexo'];
			}
			else $this->_sexo="";
		}
		else{
			$this->_id_org="";
			$this->_organizacion="";
			$this->_creator="";
			$this->_pais="";
			$this->_region="";
		}
	}
	
	//Comprueba que el usuario no sea, o no, el creador de la organización.
	public function esCreador(){
		return ($this->_creator == $this->_correo);
	}
	
	//Función que comprueba si está registrado el usuario
	public function estaRegistrado (){
		return $this->_registrado;
	}
	
	//Función que comprueba si se trata de un rol específico.
	//Se le pueden pasar múltiples roles para que compruebe si es uno de ellos, de la siguiente forma: esRol(array('admin','club','federacion'))
	public function esRol ($rol){
		if ($this->estaRegistrado()){
			//Si es un vector, estamos pasando un vector en el parámetro de entrada
			if (is_array($rol)){
				foreach ($rol as &$tipo) if ($this->_tipo == $tipo) return true;
			}
			else{
				return ($this->_tipo == $rol);
			}
			return false;
		}
	}
	
	//Comprueba que pertenezca a una organización
	public function tieneOrg(){
		return ($this->_organizacion!="");
	}
	
	//Comprueba que la organización esté activa
	public function esActiva(){
		$sql= new cMySQL();
		$sql->conectar();
		$organizacion=$this->_organizacion;
		//Comprobamos que la organización sigue activa actualmente
		$sql->ejecutarSQL("SELECT activa FROM organizacion WHERE nombre='$organizacion'");
		$numRegistros=$sql->getNumRegistros();
		if ($numRegistros >0){
			$activa=$sql->getCampoN();
			return ($activa == 1);
		}
		else return false;
	}
	
	public function esAceptada(){
		//Comprobamos que no se trate del creador de la organización, por eso no tiene creada la solicitud en la tabla solicitudes.
		if (!$this->esCreador()){
			$sql= new cMySQL();
			$sql->conectar();
			$correo = $this->_correo;
			//Comprobamos que la solicitud (en la tabla solicitudes, si no es el creador) sigue aceptada, o se ha rechazado recientemente, por lo que no podrá acceder
			$sql->ejecutarSQL("SELECT aceptada FROM solicitudes WHERE solicitor='$correo'");
			$numRegistros=$sql->getNumRegistros();
			if ($numRegistros > 0){
				$aceptada=$sql->getCampoN();
				return ($aceptada == 1);
			}
			else return false;
		}
		else return true;
	}
	
	//Devuelve un elemento privado
	public function val($valor){
		switch($valor){
			case "name": 
				return $this->_username;
				break;
			case "correo":
				return $this->_correo;
				break;
			case "tipo":
				return $this->_tipo;
				break;
			case "org":
				return $this->_organizacion;
				break;
			case "id_org":
				return $this->_id_org;
				break;
			case "creador":
				return $this->_creator;
				break;
			case "sexo":
				return $this->_sexo;
				break;
			case "pais":
				return $this->_pais;
				break;
			case "region":
				return $this->_region;
				break;
		}		
	}
	
	/*Función que se encarga de comprobar si el usuario que accede al sistema está registrado, qué tipo de rol tiene, está activo, etc. Dependerá del nivel que estemos introduciendo.
		Nivel 0 - Registro
		Nivel 1 - Rol específico
		Nivel 2 - Pertenece a organización
		Nivel 3 - Organización está activa
		Nivel 4 - La solicitud del usuario está aceptada
	*/
	public function compruebaRol ($rol,$nivel){
		global $ingreso,$noRegistrado,$responsable,$noOrganizacion,$organizacionRechazada;
		$return=1;
		for ($i=0;$i<=$nivel;$i++){
			//Nivel 0 - Registro
			if ($i == 0){
				if ($this->estaRegistrado()) $return=1;
				else $return=$noRegistrado;
			}
			//Nivel 1 - Rol específico
			if ($i == 1){
				if ($this->esRol($rol)) $return=1;
				else $return=$responsable;
			}
			//Nivel 2 - Pertenece a organización
			if ($i == 2){
				if ($this->tieneOrg()) $return=1;
				else $return=$noOrganizacion;
			}
			//Nivel 3 - Organización está activa
			if ($i == 3){
				if ($this->esActiva()) $return=1;
				else $return=$organizacionRechazada;
			}
			//Nivel 4 - La solicitud del usuario está aceptada
			if ($i == 4){
				if ($this->esAceptada()) $return=1;
				else $return=$ingreso;
			}
			if ($return!=1) return $return;
		}
		return $return;
	}
	//Función que controla los roles de menos nivel cuando se busca un nivel más profundo
	public function controlRegistro($rol,$nivel){
		$this->recogerDatos();
		if (is_array($rol)){
			foreach ($rol as &$tipo){
				if ($tipo == $this->_tipo){
					if (($tipo == "gestor") ||($tipo == "administrador")) return $this->compruebaRol ($tipo,1);
					else return $this->compruebaRol ($tipo,$nivel);
				}
			}
		}
		else return $this->compruebaRol ($rol,$nivel);
	}
	
	//AUXILIARES
	//Función que comprueba que el creador de la organización del usuario sea el dueño del campeonato.
	//$id_champ: identificador del campeonato
	public function manejaCampeonato($id_champ){
		if ($this->esRol(array("club","federacion"))){ 
			$sql= new cMySQL();
			$sql->conectar();
			$sql->ejecutarSQL("SELECT creadorChamp FROM campeonato WHERE id_campeonato='$id_champ'");
			$numRegistros=$sql->getNumRegistros();
			if ($numRegistros >0){
				$creador=$sql->getCampoN();
				return ($creador == $this->_creator);
			}
			else return false;
		}
		else return false;
	}
}
	
?>